eprllib.Utils.observation_utils — eprllib: use EnergyPlus as an environment for DRL control

Skip to main content
`Ctrl`+`K`

# eprllib.Utils.observation_utils

## Observation utilities

This module contain some utilities used within the observation space, function, and other parts of the programm related with the observations.

Functions

`get_actuator_name`(agent, ...) | This function is used to get the actuator name in the observation space.
`get_internal_variable_name`(agent, ...) | This function is used to get the internal variable name in the observation space.
`get_meter_name`(agent, meter_name) | This function is used to get the meter name in the observation space.
`get_other_obs_name`(agent, other_obs_name) | This function is used to get the other observation name in the observation space.
`get_parameter_name`(agent, parameter_name) | This function is used to get the parameter name in the observation space.
`get_parameter_prediction_name`(agent, ...) | This function is used to get the parameter prediction name in the observation space.
`get_variable_name`(agent, variable_name, ...) | This function is used to get the variable name in the observation space.